@@ -68,14 +68,6 @@ class Data:
             with open(self.filename_samples, 'w') as f:
                  df.to_csv(f, header=False, index=False, line_terminator='\n')
         
-        '''
-        if not os.path.isfile(self.filename_samples):
-            with open(self.filename_samples, "w") as file:
-                self.stoch_data['names'] + \
-                        self.inputs['objective names']:
-                    file.write('%25s, ' % name)
-                file.write('\n')
-        '''
         
     def read_stoch_parameters(self, var_values=[]):
         """
@@ -210,19 +202,6 @@ class RandomExperiment(Data):
 
         """
         
-        df = pd.read_csv(self.my_data.filename_samples)
-        df_x = df[self.my_data.stoch_data['names']]
-        df_y = df[self.my_data.inputs['objective of interest']]
-        
-        self.x_prev = df_x.to_numpy()
-        
-        self.y_prev = np.zeros((len(self.x_prev), 1))
-        y_int = df_y.to_numpy()
-        
-        for i,y in enumerate(y_int):
-            self.y_prev[i] = y
-            
-        '''
         with open(self.my_data.filename_samples, 'r') as file:
             lines = file.readlines()
             x_int = np.zeros((len(lines) - 1,
@@ -231,7 +210,7 @@ class RandomExperiment(Data):
 
             # if samples are present in the samples file
             if len(lines) > 1:
-                if (len(lines[-1].split()) !=
+                if (len(lines[-1].split(",")) !=
                     len(self.my_data.stoch_data['mean']) +
                         len(self.my_data.inputs['objective names'])):
                     raise SyntaxError(
@@ -248,7 +227,7 @@ class RandomExperiment(Data):
 
                 # read in samples and deterministic model output
                 for i, line in enumerate(lines[1:]):
-                    line_split = line.split()
+                    line_split = line.split(",")
                     x_int[i] = [float(el) for el in line_split[:len(
                         self.my_data.stoch_data['mean'])]]
                     y_int[i] = float(
@@ -258,8 +237,7 @@ class RandomExperiment(Data):
         # store samples and deterministic output
         self.y_prev = np.array(y_int)
         self.x_prev = np.array(x_int)
-        '''
-
+            
     def create_distributions(self):
         """
         Create the distributions, polynomial distributions and polynomial types
@@ -384,17 +362,6 @@ class RandomExperiment(Data):
             with open(self.my_data.filename_samples, 'a+') as f:
                 df.to_csv(f, header=False, index=False, line_terminator='\n')
 
-            '''
-            # add the samples to the samples file, no output results
-            with open(self.my_data.filename_samples, 'a+') as file:
-                for i, x_u_sample in enumerate(self.x_u):
-                    line = list(x_u_sample)
-                    for j in line:
-                        file.write('%25f ' % j)
-
-                    file.write('\n')
-            '''
-
     def evaluate(self, eval_func, params):
         """
         Evaluate the samples in the model
@@ -439,21 +406,18 @@ class RandomExperiment(Data):
             res = []
             for index, sample in enumerate(eval_dict):
                 res.append(eval_func((index + len(self.x_prev), sample), params=params))
-
-            df = pd.DataFrame(samples, columns=None)
-            df2 = pd.DataFrame(res, columns=None)
-            df3 = pd.concat([df, df2], axis=1)
-                        
-            with open(self.my_data.filename_samples, 'a+') as f:
-                df3.to_csv(f, header=False, index=False, line_terminator='\n')
-
-                '''
                 with open(self.my_data.filename_samples, 'a+') as file:
-                    line = list(samples[index]) + list(res[-1])
-                    for j in line:
-                        file.write('%25f ' % j)
+                    if isinstance(res[0], float):
+                        line = list(samples[index]) + [res[-1]]
+                    else:
+                        line = list(samples[index]) + list(res[-1])
+
+                    for index,j in enumerate(line):
+                        if index != len(line)-1:
+                            file.write('%25f,' % j)
+                        else:
+                            file.write('%25f' % j)
                     file.write('\n')
-                '''
 
         else:
             # multiprocessing
@@ -465,17 +429,20 @@ class RandomExperiment(Data):
                 enumerate(eval_dict))
             pool.close()
 
+            df = pd.DataFrame(samples, columns=None)
+            df2 = pd.DataFrame(res, columns=None)
+            df3 = pd.concat([df, df2], axis=1)
+
             # append new samples and model outputs to samples file
-            with open(self.my_data.filename_samples, 'a+') as file:
-                for i, sample in enumerate(samples):
-                    line = list(np.concatenate((sample, res[i])))
-                    for j in line:
-                        file.write('%25f ' % j)
-
-                    file.write('\n')
-
+            with open(self.my_data.filename_samples, 'a+') as f:
+                df3.to_csv(f, header=False, index=False, line_terminator='\n')
+            
         # check that the quantity of interest exists
-        if self.objective_position > len(res[0]) - 1:
+        if isinstance(res[0], float):
+            len_res = 1
+        else:
+            len_res = len(res[0])
+        if self.objective_position > len_res - 1:
             raise IndexError(""" The objective "%s" falls out of
                                  the range of predefined quantities
                                  of interest. Only %i outputs are
@@ -485,7 +452,11 @@ class RandomExperiment(Data):
 
         # combine model output for quantity of interest with previous results
         # available in samples file
-        y_res = [row[self.objective_position] for row in res]
+        
+        if len_res == 1:
+            y_res = [row for row in res]
+        else:
+            y_res = [row[self.objective_position] for row in res]
         if self.y_prev.size:
             self.y = np.vstack((self.y_prev, np.array(y_res).reshape((-1, 1))))
         else:
@@ -919,22 +890,19 @@ class PCE(RandomExperiment):
         # write sobol indices in the corresponding result file
         with open(os.path.join(self.my_experiment.my_data.path_res,
                                filename_res[:-4] + '_Sobol_indices.csv'), "w") as file:                               
-            df1.to_csv(file, index=False, line_terminator='\n')
-                               
-            '''
+
             file.write(
-                '%30s %30s %30s  \n' %
+                '%30s,%30s,%30s.  \n' %
                 ('name',
                  'First-order Sobol indices',
                  'Total-order Sobol indices'))
             indices = np.argsort(self.sensitivity['s_tot_i'])[::-1]
             for i in indices:
                 file.write(
-                    '%30s %30f %30f  \n' %
+                    '%30s,%30f,%30f  \n' %
                     (self.my_experiment.my_data.stoch_data['names'][i],
                      self.sensitivity['s_i'][i],
                      self.sensitivity['s_tot_i'][i]))
-            '''
 
     def draw(self, size):
         """
@@ -971,23 +939,7 @@ class PCE(RandomExperiment):
                                 % (self.my_experiment.my_data.inputs[
                                     'objective of interest']))), "w") as f:
             df1.to_csv(f, index=False, line_terminator='\n')
-        
-        '''
-        with open(os.path.join(self.my_experiment.my_data.path_res,
-                               ("data_pdf_%s.csv"
-                                % (self.my_experiment.my_data.inputs[
-                                    'objective of interest']))), "w") as file:
-
-
-            file.write(
-                '%25s %25s \n' %
-                (self.my_experiment.my_data.inputs['objective of interest'],
-                 'probability density'))
-            for i, j in enumerate(centers):
-                file.write('%25f %25f' % (j, density[i]))
-                file.write('\n')
-        '''
-        
+                
         # generate the cdf
         cdf = np.cumsum(density * np.diff(bins))
 
@@ -998,19 +950,4 @@ class PCE(RandomExperiment):
                                ("data_cdf_%s.csv"
                                 % (self.my_experiment.my_data.inputs[
                                     'objective of interest']))), "w") as f:
-            df1.to_csv(f, index=False, line_terminator='\n')
-
-        '''
-        with open(os.path.join(self.my_experiment.my_data.path_res,
-                               ("data_cdf_%s"
-                                % (self.my_experiment.my_data.inputs[
-                                    'objective of interest']))), "w") as file:
-
-            file.write(
-                '%25s %25s \n' %
-                (self.my_experiment.my_data.inputs['objective of interest'],
-                 'cumulative probability'))
-            for i, j in enumerate(centers):
-                file.write('%25f %25f' % (j, cdf[i]))
-                file.write('\n')
-        '''
\ No newline at end of file
+            df1.to_csv(f, index=False, line_terminator='\n')
\ No newline at end of file
